==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/StageInfoFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class StageInfoFluentImpl<A extends io.fabric8.openshift.api.model.StageInfoFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.StageInfoFluent<A>{
  public StageInfoFluentImpl() {
  }
  public StageInfoFluentImpl(io.fabric8.openshift.api.model.StageInfo instance) {
    this.withDurationMilliseconds(instance.getDurationMilliseconds()); 
    this.withName(instance.getName()); 
    this.withStartTime(instance.getStartTime()); 
    this.withSteps(instance.getSteps()); 
  }
  private java.lang.Long durationMilliseconds;
  private java.lang.String name;
  private java.lang.String startTime;
  private java.util.List<io.fabric8.openshift.api.model.StepInfoBuilder> steps =  new java.util.ArrayList<io.fabric8.openshift.api.model.StepInfoBuilder>();
  public java.lang.Long getDurationMilliseconds() {
    return this.durationMilliseconds;
  }
  public A withDurationMilliseconds(java.lang.Long durationMilliseconds) {
    this.durationMilliseconds=durationMilliseconds; return (A) this;
  }
  public java.lang.Boolean hasDurationMilliseconds() {
    return this.durationMilliseconds != null;
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getStartTime() {
    return this.startTime;
  }
  public A withStartTime(java.lang.String startTime) {
    this.startTime=startTime; return (A) this;
  }
  public java.lang.Boolean hasStartTime() {
    return this.startTime != null;
  }
  
  /**
   * Method is deprecated. use withStartTime instead.
   */
  @java.lang.Deprecated
  public A withNewStartTime(java.lang.String arg0) {
    return (A)withStartTime(new String(arg0));
  }
  public A addToSteps(java.lang.Integer index,io.fabric8.openshift.api.model.StepInfo item) {
    if (this.steps == null) {this.steps = new java.util.ArrayList<io.fabric8.openshift.api.model.StepInfoBuilder>();}
    io.fabric8.openshift.api.model.StepInfoBuilder builder = new io.fabric8.openshift.api.model.StepInfoBuilder(item);_visitables.get("steps").add(index >= 0 ? index : _visitables.get("steps").size(), builder);this.steps.add(index >= 0 ? index : steps.size(), builder); return (A)this;
  }
  public A setToSteps(java.lang.Integer index,io.fabric8.openshift.api.model.StepInfo item) {
    if (this.steps == null) {this.steps = new java.util.ArrayList<io.fabric8.openshift.api.model.StepInfoBuilder>();}
    io.fabric8.openshift.api.model.StepInfoBuilder builder = new io.fabric8.openshift.api.model.StepInfoBuilder(item);
    if (index < 0 || index >= _visitables.get("steps").size()) { _visitables.get("steps").add(builder); } else { _visitables.get("steps").set(index, builder);}
    if (index < 0 || index >= steps.size()) { steps.add(builder); } else { steps.set(index, builder);}
     return (A)this;
  }
  public A addToSteps(io.fabric8.openshift.api.model.StepInfo... items) {
    if (this.steps == null) {this.steps = new java.util.ArrayList<io.fabric8.openshift.api.model.StepInfoBuilder>();}
    for (io.fabric8.openshift.api.model.StepInfo item : items) {io.fabric8.openshift.api.model.StepInfoBuilder builder = new io.fabric8.openshift.api.model.StepInfoBuilder(item);_visitables.get("steps").add(builder);this.steps.add(builder);} return (A)this;
  }
  public A addAllToSteps(java.util.Collection<io.fabric8.openshift.api.model.StepInfo> items) {
    if (this.steps == null) {this.steps = new java.util.ArrayList<io.fabric8.openshift.api.model.StepInfoBuilder>();}
    for (io.fabric8.openshift.api.model.StepInfo item : items) {io.fabric8.openshift.api.model.StepInfoBuilder builder = new io.fabric8.openshift.api.model.StepInfoBuilder(item);_visitables.get("steps").add(builder);this.steps.add(builder);} return (A)this;
  }
  public A removeFromSteps(io.fabric8.openshift.api.model.StepInfo... items) {
    for (io.fabric8.openshift.api.model.StepInfo item : items) {io.fabric8.openshift.api.model.StepInfoBuilder builder = new io.fabric8.openshift.api.model.StepInfoBuilder(item);_visitables.get("steps").remove(builder);if (this.steps != null) {this.steps.remove(builder);}} return (A)this;
  }
  public A removeAllFromSteps(java.util.Collection<io.fabric8.openshift.api.model.StepInfo> items) {
    for (io.fabric8.openshift.api.model.StepInfo item : items) {io.fabric8.openshift.api.model.StepInfoBuilder builder = new io.fabric8.openshift.api.model.StepInfoBuilder(item);_visitables.get("steps").remove(builder);if (this.steps != null) {this.steps.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromSteps(java.util.function.Predicate<io.fabric8.openshift.api.model.StepInfoBuilder> predicate) {
    if (steps == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.StepInfoBuilder> each = steps.iterator();
    final List visitables = _visitables.get("steps");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.StepInfoBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildSteps instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.StepInfo> getSteps() {
    return build(steps);
  }
  public java.util.List<io.fabric8.openshift.api.model.StepInfo> buildSteps() {
    return build(steps);
  }
  public io.fabric8.openshift.api.model.StepInfo buildStep(java.lang.Integer index) {
    return this.steps.get(index).build();
  }
  public io.fabric8.openshift.api.model.StepInfo buildFirstStep() {
    return this.steps.get(0).build();
  }
  public io.fabric8.openshift.api.model.StepInfo buildLastStep() {
    return this.steps.get(steps.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.StepInfo buildMatchingStep(java.util.function.Predicate<io.fabric8.openshift.api.model.StepInfoBuilder> predicate) {
    for (io.fabric8.openshift.api.model.StepInfoBuilder item: steps) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingStep(java.util.function.Predicate<io.fabric8.openshift.api.model.StepInfoBuilder> predicate) {
    for (io.fabric8.openshift.api.model.StepInfoBuilder item: steps) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSteps(java.util.List<io.fabric8.openshift.api.model.StepInfo> steps) {
    if (this.steps != null) { _visitables.get("steps").removeAll(this.steps);}
    if (steps != null) {this.steps = new java.util.ArrayList<io.fabric8.openshift.api.model.StepInfoBuilder>(); for (io.fabric8.openshift.api.model.StepInfo item : steps){this.addToSteps(item);}} else { this.steps = null;} return (A) this;
  }
  public A withSteps(io.fabric8.openshift.api.model.StepInfo... steps) {
    if (this.steps != null) {this.steps.clear();}
    if (steps != null) {for (io.fabric8.openshift.api.model.StepInfo item :steps){ this.addToSteps(item);}} return (A) this;
  }
  public java.lang.Boolean hasSteps() {
    return steps != null && !steps.isEmpty();
  }
  public A addNewStep(java.lang.Long durationMilliseconds,java.lang.String name,java.lang.String startTime) {
    return (A)addToSteps(new StepInfo(durationMilliseconds, name, startTime));
  }
  public io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<A> addNewStep() {
    return new io.fabric8.openshift.api.model.StageInfoFluentImpl.StepsNestedImpl();
  }
  public io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<A> addNewStepLike(io.fabric8.openshift.api.model.StepInfo item) {
    return new io.fabric8.openshift.api.model.StageInfoFluentImpl.StepsNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<A> setNewStepLike(java.lang.Integer index,io.fabric8.openshift.api.model.StepInfo item) {
    return new io.fabric8.openshift.api.model.StageInfoFluentImpl.StepsNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<A> editStep(java.lang.Integer index) {
    if (steps.size() <= index) throw new RuntimeException("Can't edit steps. Index exceeds size.");
    return setNewStepLike(index, buildStep(index));
  }
  public io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<A> editFirstStep() {
    if (steps.size() == 0) throw new RuntimeException("Can't edit first steps. The list is empty.");
    return setNewStepLike(0, buildStep(0));
  }
  public io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<A> editLastStep() {
    int index = steps.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last steps. The list is empty.");
    return setNewStepLike(index, buildStep(index));
  }
  public io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<A> editMatchingStep(java.util.function.Predicate<io.fabric8.openshift.api.model.StepInfoBuilder> predicate) {
    int index = -1;
    for (int i=0;i<steps.size();i++) { 
    if (predicate.test(steps.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching steps. No match found.");
    return setNewStepLike(index, buildStep(index));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StageInfoFluentImpl that = (StageInfoFluentImpl) o;
    if (durationMilliseconds != null ? !durationMilliseconds.equals(that.durationMilliseconds) :that.durationMilliseconds != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (startTime != null ? !startTime.equals(that.startTime) :that.startTime != null) return false;
    if (steps != null ? !steps.equals(that.steps) :that.steps != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(durationMilliseconds,  name,  startTime,  steps,  super.hashCode());
  }
  public class StepsNestedImpl<N> extends io.fabric8.openshift.api.model.StepInfoFluentImpl<io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<N>> implements io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StepsNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.StepInfo item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.StepInfoBuilder(this, item);
    }
    StepsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.StepInfoBuilder(this);
    }
    io.fabric8.openshift.api.model.StepInfoBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) StageInfoFluentImpl.this.setToSteps(index,builder.build());
    }
    public N endStep() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/StageInfoFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class StageInfoFluentImpl<A extends io.fabric8.openshift.api.model.StageInfoFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.StageInfoFluent<A>{
  public StageInfoFluentImpl() {
  }
  public StageInfoFluentImpl(io.fabric8.openshift.api.model.StageInfo instance) {
    this.withDurationMilliseconds(instance.getDurationMilliseconds()); 
    this.withName(instance.getName()); 
    this.withStartTime(instance.getStartTime()); 
    this.withSteps(instance.getSteps()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Long durationMilliseconds;
  private java.lang.String name;
  private java.lang.String startTime;
  private java.util.List<io.fabric8.openshift.api.model.StepInfoBuilder> steps =  new java.util.ArrayList<io.fabric8.openshift.api.model.StepInfoBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Long getDurationMilliseconds() {
    return this.durationMilliseconds;
  }
  public A withDurationMilliseconds(java.lang.Long durationMilliseconds) {
    this.durationMilliseconds=durationMilliseconds; return (A) this;
  }
  public java.lang.Boolean hasDurationMilliseconds() {
    return this.durationMilliseconds != null;
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getStartTime() {
    return this.startTime;
  }
  public A withStartTime(java.lang.String startTime) {
    this.startTime=startTime; return (A) this;
  }
  public java.lang.Boolean hasStartTime() {
    return this.startTime != null;
  }
  
  /**
   * Method is deprecated. use withStartTime instead.
   */
  @java.lang.Deprecated
  public A withNewStartTime(java.lang.String arg0) {
    return (A)withStartTime(new String(arg0));
  }
  public A addToSteps(java.lang.Integer index,io.fabric8.openshift.api.model.StepInfo item) {
    if (this.steps == null) {this.steps = new java.util.ArrayList<io.fabric8.openshift.api.model.StepInfoBuilder>();}
    io.fabric8.openshift.api.model.StepInfoBuilder builder = new io.fabric8.openshift.api.model.StepInfoBuilder(item);_visitables.get("steps").add(index >= 0 ? index : _visitables.get("steps").size(), builder);this.steps.add(index >= 0 ? index : steps.size(), builder); return (A)this;
  }
  public A setToSteps(java.lang.Integer index,io.fabric8.openshift.api.model.StepInfo item) {
    if (this.steps == null) {this.steps = new java.util.ArrayList<io.fabric8.openshift.api.model.StepInfoBuilder>();}
    io.fabric8.openshift.api.model.StepInfoBuilder builder = new io.fabric8.openshift.api.model.StepInfoBuilder(item);
    if (index < 0 || index >= _visitables.get("steps").size()) { _visitables.get("steps").add(builder); } else { _visitables.get("steps").set(index, builder);}
    if (index < 0 || index >= steps.size()) { steps.add(builder); } else { steps.set(index, builder);}
     return (A)this;
  }
  public A addToSteps(io.fabric8.openshift.api.model.StepInfo... items) {
    if (this.steps == null) {this.steps = new java.util.ArrayList<io.fabric8.openshift.api.model.StepInfoBuilder>();}
    for (io.fabric8.openshift.api.model.StepInfo item : items) {io.fabric8.openshift.api.model.StepInfoBuilder builder = new io.fabric8.openshift.api.model.StepInfoBuilder(item);_visitables.get("steps").add(builder);this.steps.add(builder);} return (A)this;
  }
  public A addAllToSteps(java.util.Collection<io.fabric8.openshift.api.model.StepInfo> items) {
    if (this.steps == null) {this.steps = new java.util.ArrayList<io.fabric8.openshift.api.model.StepInfoBuilder>();}
    for (io.fabric8.openshift.api.model.StepInfo item : items) {io.fabric8.openshift.api.model.StepInfoBuilder builder = new io.fabric8.openshift.api.model.StepInfoBuilder(item);_visitables.get("steps").add(builder);this.steps.add(builder);} return (A)this;
  }
  public A removeFromSteps(io.fabric8.openshift.api.model.StepInfo... items) {
    for (io.fabric8.openshift.api.model.StepInfo item : items) {io.fabric8.openshift.api.model.StepInfoBuilder builder = new io.fabric8.openshift.api.model.StepInfoBuilder(item);_visitables.get("steps").remove(builder);if (this.steps != null) {this.steps.remove(builder);}} return (A)this;
  }
  public A removeAllFromSteps(java.util.Collection<io.fabric8.openshift.api.model.StepInfo> items) {
    for (io.fabric8.openshift.api.model.StepInfo item : items) {io.fabric8.openshift.api.model.StepInfoBuilder builder = new io.fabric8.openshift.api.model.StepInfoBuilder(item);_visitables.get("steps").remove(builder);if (this.steps != null) {this.steps.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromSteps(java.util.function.Predicate<io.fabric8.openshift.api.model.StepInfoBuilder> predicate) {
    if (steps == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.StepInfoBuilder> each = steps.iterator();
    final List visitables = _visitables.get("steps");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.StepInfoBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildSteps instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.StepInfo> getSteps() {
    return build(steps);
  }
  public java.util.List<io.fabric8.openshift.api.model.StepInfo> buildSteps() {
    return build(steps);
  }
  public io.fabric8.openshift.api.model.StepInfo buildStep(java.lang.Integer index) {
    return this.steps.get(index).build();
  }
  public io.fabric8.openshift.api.model.StepInfo buildFirstStep() {
    return this.steps.get(0).build();
  }
  public io.fabric8.openshift.api.model.StepInfo buildLastStep() {
    return this.steps.get(steps.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.StepInfo buildMatchingStep(java.util.function.Predicate<io.fabric8.openshift.api.model.StepInfoBuilder> predicate) {
    for (io.fabric8.openshift.api.model.StepInfoBuilder item: steps) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingStep(java.util.function.Predicate<io.fabric8.openshift.api.model.StepInfoBuilder> predicate) {
    for (io.fabric8.openshift.api.model.StepInfoBuilder item: steps) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSteps(java.util.List<io.fabric8.openshift.api.model.StepInfo> steps) {
    if (this.steps != null) { _visitables.get("steps").removeAll(this.steps);}
    if (steps != null) {this.steps = new java.util.ArrayList<io.fabric8.openshift.api.model.StepInfoBuilder>(); for (io.fabric8.openshift.api.model.StepInfo item : steps){this.addToSteps(item);}} else { this.steps = null;} return (A) this;
  }
  public A withSteps(io.fabric8.openshift.api.model.StepInfo... steps) {
    if (this.steps != null) {this.steps.clear();}
    if (steps != null) {for (io.fabric8.openshift.api.model.StepInfo item :steps){ this.addToSteps(item);}} return (A) this;
  }
  public java.lang.Boolean hasSteps() {
    return steps != null && !steps.isEmpty();
  }
  public A addNewStep(java.lang.Long durationMilliseconds,java.lang.String name,java.lang.String startTime) {
    return (A)addToSteps(new StepInfo(durationMilliseconds, name, startTime));
  }
  public io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<A> addNewStep() {
    return new io.fabric8.openshift.api.model.StageInfoFluentImpl.StepsNestedImpl();
  }
  public io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<A> addNewStepLike(io.fabric8.openshift.api.model.StepInfo item) {
    return new io.fabric8.openshift.api.model.StageInfoFluentImpl.StepsNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<A> setNewStepLike(java.lang.Integer index,io.fabric8.openshift.api.model.StepInfo item) {
    return new io.fabric8.openshift.api.model.StageInfoFluentImpl.StepsNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<A> editStep(java.lang.Integer index) {
    if (steps.size() <= index) throw new RuntimeException("Can't edit steps. Index exceeds size.");
    return setNewStepLike(index, buildStep(index));
  }
  public io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<A> editFirstStep() {
    if (steps.size() == 0) throw new RuntimeException("Can't edit first steps. The list is empty.");
    return setNewStepLike(0, buildStep(0));
  }
  public io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<A> editLastStep() {
    int index = steps.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last steps. The list is empty.");
    return setNewStepLike(index, buildStep(index));
  }
  public io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<A> editMatchingStep(java.util.function.Predicate<io.fabric8.openshift.api.model.StepInfoBuilder> predicate) {
    int index = -1;
    for (int i=0;i<steps.size();i++) { 
    if (predicate.test(steps.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching steps. No match found.");
    return setNewStepLike(index, buildStep(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StageInfoFluentImpl that = (StageInfoFluentImpl) o;
    if (durationMilliseconds != null ? !durationMilliseconds.equals(that.durationMilliseconds) :that.durationMilliseconds != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (startTime != null ? !startTime.equals(that.startTime) :that.startTime != null) return false;
    if (steps != null ? !steps.equals(that.steps) :that.steps != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(durationMilliseconds,  name,  startTime,  steps,  additionalProperties,  super.hashCode());
  }
  public class StepsNestedImpl<N> extends io.fabric8.openshift.api.model.StepInfoFluentImpl<io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<N>> implements io.fabric8.openshift.api.model.StageInfoFluent.StepsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StepsNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.StepInfo item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.StepInfoBuilder(this, item);
    }
    StepsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.StepInfoBuilder(this);
    }
    io.fabric8.openshift.api.model.StepInfoBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) StageInfoFluentImpl.this.setToSteps(index,builder.build());
    }
    public N endStep() {
      return and();
    }
    
  }
  
}
